@@ -2,6 +2,9 @@
  * some functions for MP4 files
 */
 
+#include <glib.h>
+#include <stdlib.h>
+
 #include "mp4ff.h"
 #include "neaacdec.h"
 #include <audacious/plugin.h>
