@@ -1,17 +1,17 @@
 /*
  * Adplug - Replayer for many OPL2/OPL3 audio file formats.
  * Copyright (C) 1999 - 2005 Simon Peter, <dn.tlp@gmx.net>, et al.
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -25,7 +25,6 @@
  *      .LAA - a raw save of a Lucas Arts Adlib music
  *             or
  *             a raw save of a LucasFilm Adlib music
- *      .CMF - Creative Music Format
  *      .SCI - the sierra "midi" format.
  *             Files must be in the form
  *             xxxNAME.sci
@@ -33,36 +32,6 @@
  *             xxxPATCH.003  (patch.003 must be saved from the
  *                            sierra resource from each game.)
  *
- * 1/9/2006: audacious libadplug
- *      Status:  MID not as fine as originally thought. Removing general MIDI detector so timidity handles these files instead.
- *      
- * 6/2/2000:  v1.0 relased by phil hassey
- *      Status:  LAA is almost perfect
- *                      - some volumes are a bit off (intrument too quiet)
- *               MID is fine (who wants to listen to MIDI vid adlib anyway)
- *               CMF is okay (still needs the adlib rythm mode implemented
- *                            for real)
- * 6/6/2000:
- *      Status:  SCI:  there are two SCI formats, orginal and advanced.
- *                    original:  (Found in SCI/EGA Sierra Adventures)
- *                               played almost perfectly, I believe
- *                               there is one mistake in the instrument
- *                               loader that causes some sounds to
- *                               not be quite right.  Most sounds are fine.
- *                    advanced:  (Found in SCI/VGA Sierra Adventures)
- *                               These are multi-track files.  (Thus the
- *                               player had to be modified to work with
- *                               them.)  This works fine.
- *                               There are also multiple tunes in each file.
- *                               I think some of them are supposed to be
- *                               played at the same time, but I'm not sure
- *                               when.
- * 8/16/2000:
- *      Status:  LAA: now EGA and VGA lucas games work pretty well
- *
- * 10/15/2005: Changes by Simon Peter
- *	Added rhythm mode support for CMF format.
- *
  * Other acknowledgements:
  *  Allegro - for the midi instruments and the midi volume table
  *  SCUMM Revisited - for getting the .LAA / .MIDs out of those
@@ -214,12 +183,12 @@ CmidPlayer::load_sierra_ins (const std::string & fname,
     }
   sprintf (pfilename + j + 3, "patch.003");
 
-  VFSFile *instfd = aud_vfs_fopen (pfilename, "rb");
+  VFSFile *instfd = vfs_fopen (pfilename, "rb");
   f = fp.open (instfd);
   free (pfilename);
   if (!f)
   {
-    aud_vfs_fclose (instfd);
+    vfs_fclose (instfd);
     return false;
   }
 
@@ -259,7 +228,7 @@ CmidPlayer::load_sierra_ins (const std::string & fname,
   }
 
   fp.close (f);
-  aud_vfs_fclose (instfd);
+  vfs_fclose (instfd);
   memcpy (smyinsbank, myinsbank, 128 * 16);
   return true;
 }
@@ -311,7 +280,7 @@ CmidPlayer::load (VFSFile * fd, const CFileProvider & fp)
     return false;
   int good;
   unsigned char s[6];
-  std::string filename (fd->uri);
+  std::string filename (vfs_get_filename (fd));
 
   f->readString ((char *) s, 6);
   good = 0;
@@ -322,17 +291,15 @@ CmidPlayer::load (VFSFile * fd, const CFileProvider & fp)
     if (s[1] == 'D' && s[2] == 'L')
       good = FILE_LUCAS;
     break;
-  case 'C':
-    if (s[1] == 'T' && s[2] == 'M' && s[3] == 'F')
-      good = FILE_CMF;
-    break;
   case 0x84:
     if (s[1] == 0x00 && load_sierra_ins (filename, fp))
+    {
       if (s[2] == 0xf0)
         good = FILE_ADVSIERRA;
       else
         good = FILE_SIERRA;
     break;
+    }
   default:
     if (s[4] == 'A' && s[5] == 'D')
       good = FILE_OLDLUCAS;
@@ -851,7 +818,7 @@ CmidPlayer::update ()
              if (w!=0)
              {
              midiprintf("\n<%d>",w);
-             f = 
+             f =
              ((float)w/(float)deltas)*((float)msqtr/(float)1000000);
              if (doing==1) f=0; //not playing yet. don't wait yet
              }
@@ -900,10 +867,12 @@ CmidPlayer::update ()
   midiprintf ("\n");
   for (i = 0; i < 16; i++)
     if (track[i].on)
+    {
       if (track[i].pos < track[i].tend)
         midiprintf ("<%d>", track[i].iwait);
       else
         midiprintf ("stop");
+    }
 
   /*
      if (ret==0 && type==FILE_ADVSIERRA)
@@ -931,7 +900,7 @@ CmidPlayer::getrefresh ()
 void
 CmidPlayer::rewind (int subsong)
 {
-  long i, j, n, m, l;
+  long i, j, l;
   long o_sierra_pos;
   unsigned char ins[16];
 
@@ -1001,55 +970,6 @@ CmidPlayer::rewind (int subsong)
     track[curtrack].spos = pos;
     midiprintf ("tracklen:%ld\n", track[curtrack].tend);
     break;
-  case FILE_CMF:
-    getnext (3);                // ctmf
-    getnexti (2);               //version
-    n = getnexti (2);           // instrument offset
-    m = getnexti (2);           // music offset
-    deltas = getnexti (2);      //ticks/qtr note
-    msqtr = 1000000 / getnexti (2) * deltas;
-    //the stuff in the cmf is click ticks per second..
-
-    i = getnexti (2);
-    if (i)
-      title = (char *) data + i;
-    i = getnexti (2);
-    if (i)
-      author = (char *) data + i;
-    i = getnexti (2);
-    if (i)
-      remarks = (char *) data + i;
-
-    getnext (16);               // channel in use table ..
-    i = getnexti (2);           // num instr
-    if (i > 128)
-      i = 128;                  // to ward of bad numbers...
-    getnexti (2);               //basic tempo
-
-    midiprintf ("\nioff:%d\nmoff%d\ndeltas:%ld\nmsqtr:%ld\nnumi:%d\n",
-                n, m, deltas, msqtr, i);
-    pos = n;                    // jump to instruments
-    tins = i;
-    for (j = 0; j < i; j++)
-    {
-      midiprintf ("\n%d: ", j);
-      for (l = 0; l < 16; l++)
-      {
-        myinsbank[j][l] = (unsigned char) getnext (1);
-        midiprintf ("%2X ", myinsbank[j][l]);
-      }
-    }
-
-    for (i = 0; i < 16; i++)
-      ch[i].nshift = -13;
-
-    adlib_style = CMF_STYLE;
-
-    curtrack = 0;
-    track[curtrack].on = 1;
-    track[curtrack].tend = flen;    // music until the end of the file
-    track[curtrack].spos = m;   //jump to midi music
-    break;
   case FILE_OLDLUCAS:
     msqtr = 250000;
     pos = 9;
@@ -1173,8 +1093,6 @@ std::string CmidPlayer::gettype ()
     return std::string ("LucasArts AdLib MIDI");
   case FILE_MIDI:
     return std::string ("General MIDI");
-  case FILE_CMF:
-    return std::string ("Creative Music Format (CMF MIDI)");
   case FILE_OLDLUCAS:
     return std::string ("Lucasfilm Adlib MIDI");
   case FILE_ADVSIERRA:
