@@ -49,6 +49,13 @@ enum
   LISTMIXER_N_COLUMNS
 };
 
+/* GCC does not like casting func * * to void * *. */
+static void * get_symbol (GModule * mod, const gchar * name)
+{
+    void * sym = NULL;
+    g_module_symbol (mod, name, & sym);
+    return sym;
+}
 
 void i_configure_ev_portlv_changetoggle( GtkCellRendererToggle * rdtoggle ,
                                          gchar * path_str , gpointer data )
@@ -249,7 +256,6 @@ void i_configure_gui_tab_alsa( GtkWidget * alsa_page_alignment ,
     GtkCellRenderer *mixer_card_cmb_text_rndr, *mixer_ctl_cmb_text_rndr;
     GtkWidget *mixer_card_cmb_evbox, *mixer_card_cmb, *mixer_card_label;
     GtkWidget *mixer_ctl_cmb_evbox, *mixer_ctl_cmb, *mixer_ctl_label;
-    GtkTooltips *tips;
 
     amidiplug_cfg_alsa_t * alsacfg = amidiplug_cfg_backend->alsa;
 
@@ -265,16 +271,15 @@ void i_configure_gui_tab_alsa( GtkWidget * alsa_page_alignment ,
     if ( strlen( alsacfg->alsa_seq_wports ) > 0 )
       portstring_from_cfg = g_strsplit( alsacfg->alsa_seq_wports , "," , 0 );
 
-    tips = gtk_tooltips_new();
-    g_object_set_data_full( G_OBJECT(alsa_page_alignment) , "tt" , tips , g_object_unref );
-
     /* it's legit to assume that this can't fail,
        since the module is present in the backend_list */
     alsa_module = g_module_open( alsa_module_pathfilename , 0 );
-    g_module_symbol( alsa_module , "sequencer_port_get_list" , (gpointer*)&get_port_list );
-    g_module_symbol( alsa_module , "sequencer_port_free_list" , (gpointer*)&free_port_list );
-    g_module_symbol( alsa_module , "alsa_card_get_list" , (gpointer*)&get_card_list );
-    g_module_symbol( alsa_module , "alsa_card_free_list" , (gpointer*)&free_card_list );
+
+    get_port_list = get_symbol (alsa_module, "sequencer_port_get_list");
+    free_port_list = get_symbol (alsa_module, "sequencer_port_free_list");
+    get_card_list = get_symbol (alsa_module, "alsa_card_get_list");
+    free_card_list = get_symbol (alsa_module, "alsa_card_free_list");
+
     /* get an updated list of writable ALSA MIDI ports and ALSA-enabled sound cards*/
     wports = get_port_list(); wports_h = wports;
     scards = get_card_list(); scards_h = scards;
@@ -416,26 +421,6 @@ void i_configure_gui_tab_alsa( GtkWidget * alsa_page_alignment ,
     free_card_list( scards_h );
     free_port_list( wports_h );
     g_module_close( alsa_module );
-
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , port_lv ,
-                        _("* Select ALSA output ports *\n"
-                        "MIDI events will be sent to the ports selected here. In example, if your "
-                        "audio card provides a hardware synth and you want to play MIDI with it, "
-                        "you'll probably want to select the wavetable synthesizer ports.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , mixer_card_cmb_evbox ,
-                        _("* Select ALSA mixer card *\n"
-                        "The ALSA backend outputs directly through ALSA, it doesn't use effect "
-                        "and ouput plugins from the player. During playback, the player volume"
-                        "slider will manipulate the mixer control you select here. "
-                        "If you're using wavetable synthesizer ports, you'll probably want to "
-                        "select the Synth control here.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , mixer_ctl_cmb_evbox ,
-                        _("* Select ALSA mixer control *\n"
-                        "The ALSA backend outputs directly through ALSA, it doesn't use effect "
-                        "and ouput plugins from the player. During playback, the player volume "
-                        "slider will manipulate the mixer control you select here. "
-                        "If you're using wavetable synthesizer ports, you'll probably want to "
-                        "select the Synth control here.") , "" );
   }
   else
   {
@@ -460,7 +445,7 @@ void i_configure_gui_tablabel_alsa( GtkWidget * alsa_page_alignment ,
   pagelabel_image_pix = gdk_pixbuf_new_from_xpm_data( (const gchar **)backend_alsa_icon_xpm );
   pagelabel_image = gtk_image_new_from_pixbuf( pagelabel_image_pix ); g_object_unref( pagelabel_image_pix );
   pagelabel_label = gtk_label_new( "" );
-  gtk_label_set_markup( GTK_LABEL(pagelabel_label) , "<span size=\"smaller\">ALSA\nbackend</span>" );
+  gtk_label_set_markup( GTK_LABEL(pagelabel_label) , _("<span size=\"smaller\">ALSA\nbackend</span>") );
   gtk_label_set_justify( GTK_LABEL(pagelabel_label) , GTK_JUSTIFY_CENTER );
   gtk_box_pack_start( GTK_BOX(pagelabel_vbox) , pagelabel_image , FALSE , FALSE , 1 );
   gtk_box_pack_start( GTK_BOX(pagelabel_vbox) , pagelabel_label , FALSE , FALSE , 1 );
