@@ -18,6 +18,12 @@
 *
 */
 
+#include <gtk/gtk.h>
+
+#include <audacious/drct.h>
+#include <audacious/gtk-compat.h>
+#include <audacious/misc.h>
+#include <audacious/plugin.h>
 
 #include "i_configure.h"
 #include "i_configure_private.h"
@@ -26,17 +32,13 @@
 #include "i_configure-ap.h"
 #include "i_configure-alsa.h"
 #include "i_configure-fluidsynth.h"
-#include "i_configure-dummy.h"
 #include "i_utils.h"
-#include <audacious/auddrct.h>
-
 
 amidiplug_cfg_backend_t * amidiplug_cfg_backend;
 
 
 void i_configure_ev_bcancel( gpointer );
 void i_configure_ev_bapply( GtkWidget * , gpointer );
-void i_configure_ev_bokcheck( GtkWidget * , gpointer );
 void i_configure_ev_bok( GtkWidget * , gpointer );
 void i_configure_cfg_backend_alloc( void );
 void i_configure_cfg_backend_free( void );
@@ -69,7 +71,7 @@ void i_configure_ev_browse_for_entry( GtkWidget * target_entry )
 {
   GtkWidget *parent_window = gtk_widget_get_toplevel( target_entry );
   GtkFileChooserAction act = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(target_entry),"fc-act"));
-  if ( GTK_WIDGET_TOPLEVEL(parent_window) )
+  if (gtk_widget_is_toplevel (parent_window))
   {
     GtkWidget *browse_dialog = gtk_file_chooser_dialog_new( _("AMIDI-Plug - select file") ,
                                                             GTK_WINDOW(parent_window) , act ,
@@ -89,6 +91,13 @@ void i_configure_ev_browse_for_entry( GtkWidget * target_entry )
   }
 }
 
+static void commit_cb (GtkWidget * button, void * unused)
+{
+    if (aud_drct_get_playing ())
+        aud_drct_stop ();
+
+    g_signal_emit_by_name (button, "ap-commit");
+}
 
 void i_configure_gui( void )
 {
@@ -101,7 +110,6 @@ void i_configure_gui( void )
 
   GtkWidget *ap_page_alignment, *ap_pagelabel_alignment; /* amidi-plug */
   GtkWidget *alsa_page_alignment, *alsa_pagelabel_alignment; /* alsa */
-  GtkWidget *dumm_page_alignment, *dumm_pagelabel_alignment; /* dummy */
   GtkWidget *fsyn_page_alignment, *fsyn_pagelabel_alignment; /* fluidsynth */
 
   GSList *backend_list = NULL, *backend_list_h = NULL;
@@ -123,14 +131,13 @@ void i_configure_gui( void )
   g_signal_connect( G_OBJECT(configwin) , "destroy" ,
                     G_CALLBACK(gtk_widget_destroyed) , &configwin );
   button_ok = gtk_button_new_from_stock( GTK_STOCK_OK );
-  if ( g_signal_lookup( "ap-commit" , GTK_WIDGET_TYPE(button_ok) ) == 0 )
-  {
-    g_signal_new( "ap-commit" , GTK_WIDGET_TYPE(button_ok) ,
-                  G_SIGNAL_ACTION , 0 , NULL , NULL ,
-                  g_cclosure_marshal_VOID__VOID , G_TYPE_NONE , 0 );
-  }
-  g_signal_connect( G_OBJECT(button_ok) , "clicked" ,
-                    G_CALLBACK(i_configure_ev_bokcheck) , configwin );
+
+  if (! g_signal_lookup ("ap-commit", G_OBJECT_TYPE (button_ok)))
+    g_signal_new ("ap-commit", G_OBJECT_TYPE (button_ok), G_SIGNAL_ACTION, 0,
+     NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+
+  g_signal_connect (button_ok, "clicked", (GCallback) commit_cb, NULL);
+
   cw_hints.min_width = 480; cw_hints.min_height = -1;
   gtk_window_set_geometry_hints( GTK_WINDOW(configwin) , GTK_WIDGET(configwin) ,
                                  &cw_hints , GDK_HINT_MIN_SIZE );
@@ -173,15 +180,6 @@ void i_configure_gui( void )
   gtk_notebook_append_page( GTK_NOTEBOOK(configwin_notebook) ,
                             fsyn_page_alignment , fsyn_pagelabel_alignment );
 
-  /* DUMMY BACKEND CONFIGURATION TAB */
-  dumm_pagelabel_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
-  dumm_page_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
-  gtk_alignment_set_padding( GTK_ALIGNMENT(dumm_page_alignment) , 3 , 3 , 8 , 3 );
-  i_configure_gui_tab_dumm( dumm_page_alignment , backend_list , button_ok );
-  i_configure_gui_tablabel_dumm( dumm_pagelabel_alignment , backend_list , button_ok );
-  gtk_notebook_append_page( GTK_NOTEBOOK(configwin_notebook) ,
-                            dumm_page_alignment , dumm_pagelabel_alignment );
-
   i_backend_list_free( backend_list_h ); /* done, free the list of available backends */
 
   /* horizontal separator and buttons */
@@ -220,38 +218,9 @@ void i_configure_ev_bapply( GtkWidget * button_apply , gpointer configwin )
 {
   GtkWidget *button_ok = g_object_get_data( G_OBJECT(button_apply) , "bok" );
   g_object_set_data( G_OBJECT(button_ok) , "bapply_pressed" , GUINT_TO_POINTER(1) );
-  i_configure_ev_bokcheck( button_ok , configwin );
+  commit_cb (button_ok, NULL);
 }
 
-
-void i_configure_ev_bokcheck( GtkWidget * button_ok , gpointer configwin )
-{
-  if ( audacious_drct_get_playing() || audacious_drct_get_paused() )
-  {
-    /* we can't change settings while a song is being played */
-    static GtkWidget * configwin_warnmsg = NULL;
-    g_object_set_data( G_OBJECT(button_ok) , "bapply_pressed" , GUINT_TO_POINTER(0) );
-    if ( configwin_warnmsg != NULL )
-    {
-      gtk_window_present(GTK_WINDOW(configwin_warnmsg));
-    }
-    else
-    {
-      configwin_warnmsg = (GtkWidget*)i_message_gui( _("AMIDI-Plug message") ,
-                                        _("Please stop the player before changing AMIDI-Plug settings.") ,
-                                        AMIDIPLUG_MESSAGE_WARN , configwin , FALSE );
-      g_signal_connect( G_OBJECT(configwin_warnmsg) , "destroy" ,
-                        G_CALLBACK(gtk_widget_destroyed) , &configwin_warnmsg );
-      gtk_widget_show_all( configwin_warnmsg );
-    }
-  }
-  else
-  {
-    g_signal_emit_by_name( G_OBJECT(button_ok) , "ap-commit" ); /* call commit actions */
-  }
-}
-
-
 void i_configure_ev_bok( GtkWidget * button_ok , gpointer configwin )
 {
   DEBUGMSG( "saving configuration...\n" );
@@ -294,7 +263,6 @@ void i_configure_cfg_backend_alloc( void )
 
   i_configure_cfg_alsa_alloc(); /* alloc alsa backend configuration */
   i_configure_cfg_fsyn_alloc(); /* alloc fluidsynth backend configuration */
-  i_configure_cfg_dumm_alloc(); /* alloc dummy backend configuration */
 }
 
 
@@ -302,7 +270,6 @@ void i_configure_cfg_backend_free( void )
 {
   i_configure_cfg_alsa_free(); /* free alsa backend configuration */
   i_configure_cfg_fsyn_free(); /* free fluidsynth backend configuration */
-  i_configure_cfg_dumm_free(); /* free dummy backend configuration */
 
   g_free( amidiplug_cfg_backend );
 }
@@ -317,7 +284,6 @@ void i_configure_cfg_backend_read( void )
 
   i_configure_cfg_alsa_read( cfgfile ); /* get alsa backend configuration */
   i_configure_cfg_fsyn_read( cfgfile ); /* get fluidsynth backend configuration */
-  i_configure_cfg_dumm_read( cfgfile ); /* get dummy backend configuration */
 
   if ( cfgfile != NULL )
     i_pcfg_free(cfgfile);
@@ -338,7 +304,6 @@ void i_configure_cfg_backend_save( void )
 
   i_configure_cfg_alsa_save( cfgfile ); /* save alsa backend configuration */
   i_configure_cfg_fsyn_save( cfgfile ); /* save fluidsynth backend configuration */
-  i_configure_cfg_dumm_save( cfgfile ); /* save dummy backend configuration */
 
   i_pcfg_write_to_file( cfgfile , config_pathfilename );
   i_pcfg_free( cfgfile );
@@ -416,8 +381,5 @@ void i_configure_cfg_ap_save( void )
 
 gchar * i_configure_cfg_get_file( void )
 {
-  gchar * config_datadir = (gchar*)audacious_get_localdir();
-  gchar * config_pathfilename = g_build_filename( config_datadir , "amidi-plug.conf" , NULL );
-  g_free( config_datadir );
-  return config_pathfilename;
+  return g_build_filename (aud_get_path (AUD_PATH_USER_DIR), "amidi-plug.conf", NULL);
 }
