@@ -28,21 +28,9 @@
 #include <glib.h>
 #include <audacious/plugin.h>
 
-void aosd_init ( void );
+gboolean aosd_init (void);
 void aosd_cleanup ( void );
 void aosd_configure ( void );
 void aosd_about ( void );
 
-GeneralPlugin aosd_gp =
-{
-    NULL,						/* handle */
-    NULL,						/* filename */
-    -1,						/* session */
-    "Audacious OSD " AOSD_VERSION_PLUGIN,	/* description */
-    aosd_init,					/* init */
-    aosd_about,					/* about */
-    aosd_configure,				/* configure */
-    aosd_cleanup					/* cleanup */
-};
-
 #endif /* !_I_AOSD_H */
