@@ -4,7 +4,7 @@
  *  Copyright (c) 2007 - 2008  Sascha Hlusiak <contact@saschahlusiak.de>
  *  Name: plugin.c
  *  Description: plugin.c
- * 
+ *
  *  Part of this code is from itouch-ctrl plugin.
  *  Authors of itouch-ctrl are listed below:
  *
@@ -30,19 +30,25 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with audacious-hotkey; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
 
 #include <stdio.h>
+#include <stdlib.h>
+
 #include <X11/XF86keysym.h>
 
+#include <gdk/gdk.h>
 #include <gdk/gdkx.h>
-#include <audacious/plugin.h>
-#include <audacious/auddrct.h>
+#include <gtk/gtk.h>
 
+#include <audacious/drct.h>
 #include <audacious/i18n.h>
+#include <audacious/misc.h>
+#include <audacious/plugin.h>
+#include <libaudcore/hook.h>
 
 #include "plugin.h"
 #include "gui.h"
@@ -50,7 +56,7 @@
 
 
 /* func defs */
-static void init (void);
+static gboolean init (void);
 static void cleanup (void);
 
 
@@ -58,21 +64,14 @@ static void cleanup (void);
 static PluginConfig plugin_cfg;
 static gboolean loaded = FALSE;
 
-
-
-static GeneralPlugin audacioushotkey =
-{
-	.description = "Global Hotkey",
+AUD_GENERAL_PLUGIN
+(
+	.name = "Global Hotkey",
 	.init = init,
 	.about = show_about,
 	.configure = show_configure,
 	.cleanup = cleanup
-};
-
-GeneralPlugin *hotkey_gplist[] = { &audacioushotkey, NULL };
-SIMPLE_GENERAL_PLUGIN(hotkey, hotkey_gplist);
-
-
+)
 
 PluginConfig* get_config(void)
 {
@@ -80,16 +79,23 @@ PluginConfig* get_config(void)
 }
 
 
-/* 
+/*
  * plugin activated
  */
-static void init (void)
+static gboolean init (void)
 {
+	if (! gtk_init_check (NULL, NULL))
+	{
+		fprintf (stderr, "hotkey: GTK+ initialization failed.\n");
+		return FALSE;
+	}
+
 	setup_filter();
 	load_config ( );
 	grab_keys ( );
 
 	loaded = TRUE;
+	return TRUE;
 }
 
 /* handle keys */
@@ -98,12 +104,12 @@ gboolean handle_keyevent (EVENT event)
 	gint current_volume, old_volume;
 	static gint volume_static = 0;
 	gboolean play, mute;
-	
+
 	/* playing or not */
-	play = audacious_drct_is_playing ();
-	
+	play = aud_drct_get_playing ();
+
 	/* get current volume */
-	audacious_drct_get_volume_main (&current_volume);
+	aud_drct_get_volume_main (&current_volume);
 	old_volume = current_volume;
 	if (current_volume)
 	{
@@ -120,15 +126,15 @@ gboolean handle_keyevent (EVENT event)
 		if (!mute)
 		{
 			volume_static = current_volume;
-			audacious_drct_set_main_volume (0);
+			aud_drct_set_volume_main (0);
 			mute = TRUE;
 		} else {
-			audacious_drct_set_main_volume (volume_static);
+			aud_drct_set_volume_main (volume_static);
 			mute = FALSE;
 		}
 		return TRUE;
 	}
-	
+
 	/* decreace volume */
 	if (event == EVENT_VOL_DOWN)
 	{
@@ -138,21 +144,21 @@ gboolean handle_keyevent (EVENT event)
 			old_volume = 0;
 			mute = FALSE;
 		}
-			
+
 		if ((current_volume -= plugin_cfg.vol_decrement) < 0)
 		{
 			current_volume = 0;
 		}
-			
+
 		if (current_volume != old_volume)
 		{
-			audacious_drct_set_main_volume (current_volume);
+			aud_drct_set_volume_main (current_volume);
 		}
-			
+
 		old_volume = current_volume;
 		return TRUE;
 	}
-	
+
 	/* increase volume */
 	if (event == EVENT_VOL_UP)
 	{
@@ -162,110 +168,99 @@ gboolean handle_keyevent (EVENT event)
 			old_volume = 0;
 			mute = FALSE;
 		}
-			
+
 		if ((current_volume += plugin_cfg.vol_increment) > 100)
 		{
 			current_volume = 100;
 		}
-			
+
 		if (current_volume != old_volume)
 		{
-			audacious_drct_set_main_volume (current_volume);
+			aud_drct_set_volume_main (current_volume);
 		}
-			
+
 		old_volume = current_volume;
 		return TRUE;
 	}
-	
+
 	/* play */
 	if (event == EVENT_PLAY)
 	{
-		audacious_drct_play ();
+		aud_drct_play ();
 		return TRUE;
 	}
 
 	/* pause */
 	if (event == EVENT_PAUSE)
 	{
-		if (!play) audacious_drct_play ();
-		else audacious_drct_pause ();
+		if (!play) aud_drct_play ();
+		else aud_drct_pause ();
 
 		return TRUE;
 	}
-	
+
 	/* stop */
 	if (event == EVENT_STOP)
 	{
-		audacious_drct_stop ();
+		aud_drct_stop ();
 		return TRUE;
 	}
-	
-	/* prev track */	
+
+	/* prev track */
 	if (event == EVENT_PREV_TRACK)
 	{
-		audacious_drct_playlist_prev ();
+		aud_drct_pl_prev ();
 		return TRUE;
 	}
-	
+
 	/* next track */
 	if (event == EVENT_NEXT_TRACK)
 	{
-		audacious_drct_playlist_next ();
+		aud_drct_pl_next ();
 		return TRUE;
 	}
 
 	/* forward */
 	if (event == EVENT_FORWARD)
 	{
-		gint time = audacious_drct_get_output_time();
-		time += 5000; /* Jump 5s into future */
-		audacious_drct_jump_to_time(time);
+		aud_drct_seek (aud_drct_get_time () + 5000);
 		return TRUE;
 	}
 
 	/* backward */
 	if (event == EVENT_BACKWARD)
 	{
-		gint time = audacious_drct_get_output_time();
+		gint time = aud_drct_get_time ();
 		if (time > 5000) time -= 5000; /* Jump 5s back */
 			else time = 0;
-		audacious_drct_jump_to_time(time);
+		aud_drct_seek (time);
 		return TRUE;
 	}
 
 	/* Open Jump-To-File dialog */
 	if (event == EVENT_JUMP_TO_FILE)
 	{
-		audacious_drct_show_jtf_box();
+		aud_interface_show_jump_to_track ();
 		return TRUE;
 	}
 
 	/* Toggle Windows */
 	if (event == EVENT_TOGGLE_WIN)
 	{
-		static gboolean is_main, is_eq, is_pl;
-		is_main = audacious_drct_main_win_is_visible();
-		if (is_main) { /* Hide windows */
-			is_pl = audacious_drct_pl_win_is_visible();
-			is_eq = audacious_drct_eq_win_is_visible();
-			audacious_drct_main_win_toggle(FALSE);
-			audacious_drct_pl_win_toggle(FALSE);
-			audacious_drct_eq_win_toggle(FALSE);
-		} else { /* Show hidden windows */
-			audacious_drct_main_win_toggle(TRUE);
-			audacious_drct_pl_win_toggle(is_pl);
-			audacious_drct_eq_win_toggle(is_eq);
-			audacious_drct_activate();
-		}
+		aud_interface_show (! (aud_interface_is_shown () && aud_interface_is_focused ()));
 		return TRUE;
 	}
 
 	/* Show OSD through AOSD plugin*/
 	if (event == EVENT_SHOW_AOSD)
 	{
-		aud_hook_call("aosd toggle", NULL);
+		hook_call("aosd toggle", NULL);
 		return TRUE;
 	}
+	else if (event == EVENT_TOGGLE_REPEAT)
+		aud_set_bool (NULL, "repeat", ! aud_get_bool (NULL, "repeat"));
+	else if (event == EVENT_TOGGLE_SHUFFLE)
+		aud_set_bool (NULL, "shuffle", ! aud_get_bool (NULL, "shuffle"));
 
 	return FALSE;
 }
@@ -318,30 +313,27 @@ void load_defaults (void)
 /* load plugin configuration */
 void load_config (void)
 {
-	mcs_handle_t *cfdb;
 	HotkeyConfiguration *hotkey;
 	int i,max;
-	
+
 	/* default volume level */
 	plugin_cfg.vol_increment = 4;
 	plugin_cfg.vol_decrement = 4;
 
-	/* open configuration database */
-	cfdb = aud_cfg_db_open ( );
 	hotkey = &(plugin_cfg.first);
 	hotkey->next = NULL;
 	hotkey->key = 0;
 	hotkey->mask = 0;
 	hotkey->event = 0;
 	hotkey->type = TYPE_KEY;
-	max = 0;
-	aud_cfg_db_get_int (cfdb, "globalHotkey", "NumHotkeys", &max);
+
+	max = aud_get_int ("globalHotkey", "NumHotkeys");
 	if (max == 0)
 		load_defaults();
 	else for (i=0; i<max; i++)
 	{
 		gchar *text = NULL;
-		gint value;
+
 		if (hotkey->key) {
 			hotkey->next = (HotkeyConfiguration*)
 				malloc(sizeof (HotkeyConfiguration));
@@ -353,64 +345,56 @@ void load_config (void)
 			hotkey->type = TYPE_KEY;
 		}
 		text = g_strdup_printf("Hotkey_%d_key", i);
-		aud_cfg_db_get_int (cfdb, "globalHotkey", text, &(hotkey->key));
+		hotkey->key = aud_get_int ("globalHotkey", text);
 		g_free(text);
 
 		text = g_strdup_printf("Hotkey_%d_mask", i);
-		aud_cfg_db_get_int (cfdb, "globalHotkey", text, &(hotkey->mask));
+		hotkey->mask = aud_get_int ("globalHotkey", text);
 		g_free(text);
 
 		text = g_strdup_printf("Hotkey_%d_type", i);
-		aud_cfg_db_get_int (cfdb, "globalHotkey", text, &(hotkey->type));
+		hotkey->type = aud_get_int ("globalHotkey", text);
 		g_free(text);
 
 		text = g_strdup_printf("Hotkey_%d_event", i);
-		value = (gint)hotkey->event;
-		aud_cfg_db_get_int (cfdb, "globalHotkey", text, &value);
-		hotkey->event = (EVENT) value;
+		hotkey->event = aud_get_int ("globalHotkey", text);
 		g_free(text);
 	}
-
-	aud_cfg_db_close (cfdb);
 }
 
 /* save plugin configuration */
 void save_config (void)
 {
-	mcs_handle_t *cfdb;
 	int max;
 	HotkeyConfiguration *hotkey;
 
-	/* open configuration database */
-	cfdb = aud_cfg_db_open ( );
 	hotkey = &(plugin_cfg.first);
 	max = 0;
 	while (hotkey) {
 		gchar *text = NULL;
 		if (hotkey->key) {
 			text = g_strdup_printf("Hotkey_%d_key", max);
-			aud_cfg_db_set_int (cfdb, "globalHotkey", text, hotkey->key);
+			aud_set_int ("globalHotkey", text, hotkey->key);
 			g_free(text);
 
 			text = g_strdup_printf("Hotkey_%d_mask", max);
-			aud_cfg_db_set_int (cfdb, "globalHotkey", text, hotkey->mask);
+			aud_set_int ("globalHotkey", text, hotkey->mask);
 			g_free(text);
 
 			text = g_strdup_printf("Hotkey_%d_type", max);
-			aud_cfg_db_set_int (cfdb, "globalHotkey", text, hotkey->type);
+			aud_set_int ("globalHotkey", text, hotkey->type);
 			g_free(text);
 
 			text = g_strdup_printf("Hotkey_%d_event", max);
-			aud_cfg_db_set_int (cfdb, "globalHotkey", text, hotkey->event);
+			aud_set_int ("globalHotkey", text, hotkey->event);
 			g_free(text);
 			max++;
 		}
 
 		hotkey = hotkey->next;
 	}
-	aud_cfg_db_set_int (cfdb, "globalHotkey", "NumHotkeys", max);
 
-	aud_cfg_db_close (cfdb);
+	aud_set_int ("globalHotkey", "NumHotkeys", max);
 }
 
 static void cleanup (void)
