@@ -11,25 +11,35 @@
 //mmap()
 #include <unistd.h>
 #include <sys/mman.h>
+#include <cstdlib>
 
 #include "arch_raw.h"
 
 arch_Raw::arch_Raw(const string& aFileName)
 {
-	mFileDesc = aud_vfs_fopen(aFileName.c_str(), "rb");
-
-	//open and mmap the file
-	if(mFileDesc == NULL)
+	mFileDesc = vfs_fopen(aFileName.c_str(), "r");
+	if (!mFileDesc)
 	{
 		mSize = 0;
 		return;
 	}
-	aud_vfs_fseek(mFileDesc, 0, SEEK_END);
-	mSize = aud_vfs_ftell(mFileDesc);
-	aud_vfs_fseek(mFileDesc, 0, SEEK_SET);
+
+	mSize = vfs_fsize(mFileDesc);
+	if (mSize <= 0)
+	{
+		vfs_fclose(mFileDesc);
+		mSize = 0;
+		return;
+	}
 
 	mMap = malloc(mSize);
-	aud_vfs_fread(mMap, 1, mSize, mFileDesc);
+	if (vfs_fread(mMap, 1, mSize, mFileDesc) < mSize)
+	{
+		free(mMap);
+		vfs_fclose(mFileDesc);
+		mSize = 0;
+		return;
+	}
 }
 
 arch_Raw::~arch_Raw()
@@ -37,7 +47,7 @@ arch_Raw::~arch_Raw()
 	if(mSize != 0)
 	{
 		free(mMap);
-		aud_vfs_fclose(mFileDesc);
+		vfs_fclose(mFileDesc);
 	}
 }
 
