@@ -5,29 +5,23 @@
  */
 
 #include <fstream>
+#include <stdint.h>
 #include <unistd.h>
 #include <math.h>
 
+#include <libmodplug/stdafx.h>
+#include <libmodplug/sndfile.h>
+
+extern "C" {
+#include <audacious/debug.h>
+#include <audacious/misc.h>
+}
+
 #include "modplugbmp.h"
-#include "stdafx.h"
-#include "sndfile.h"
 #include "stddefs.h"
 #include "archive/open.h"
-extern "C" {
-#include <audacious/configdb.h>
-#include <audacious/output.h>
-#include <audacious/strings.h>
-}
 
-static char* format_and_free_ti( Tuple* ti, int* length )
-{
-        char* result = aud_tuple_formatter_make_title_string(ti, aud_get_gentitle_format());
-        if ( result )
-                *length = aud_tuple_get_int(ti, FIELD_LENGTH, NULL);
-        aud_tuple_free((void *) ti);
-
-        return result;
-}
+static gboolean stop_flag = FALSE;
 
 // ModplugXMMS member functions ===============================
 
@@ -35,73 +29,67 @@ static char* format_and_free_ti( Tuple* ti, int* length )
 ModplugXMMS::ModplugXMMS()
 {
 	mSoundFile = new CSoundFile;
-	mOutPlug = NULL;
+    control_mutex = g_mutex_new ();
+    control_cond = g_cond_new ();
 }
 ModplugXMMS::~ModplugXMMS()
 {
 	delete mSoundFile;
+    g_mutex_free (control_mutex);
+    g_cond_free (control_cond);
 }
 
-ModplugXMMS::Settings::Settings()
-{
-	mSurround       = true;
-	mOversamp       = true;
-	mReverb         = false;
-	mMegabass       = false;
-	mNoiseReduction = true;
-	mVolumeRamp     = true;
-	mFastinfo       = true;
-	mUseFilename    = false;
-	mGrabAmigaMOD   = true;
-
-	mChannels       = 2;
-	mFrequency      = 44100;
-	mBits           = 16;
-	mResamplingMode = SRCMODE_POLYPHASE;
-
-	mReverbDepth    = 30;
-	mReverbDelay    = 100;
-	mBassAmount     = 40;
-	mBassRange      = 30;
-	mSurroundDepth  = 20;
-	mSurroundDelay  = 20;
-	
-	mPreamp         = false;
-	mPreampLevel    = 0.0f;
-	
-	mLoopCount      = 0;   //don't loop
-}
+static const gchar * const modplug_defaults[] = {
+ "Surround", "TRUE",
+ "Oversampling", "TRUE",
+ "Megabass", "FALSE",
+ "NoiseReduction", "TRUE",
+ "VolumeRamp", "TRUE",
+ "Reverb", "FALSE",
+ "Fastinfo", "TRUE",
+ "UseFileName", "FALSE",
+ "GrabAmigaMOD", "TRUE",
+ "PreAmp", "FALSE",
+ "PreAmpLevel", "0",
+ "Channels", "2",
+ "Bits", "16",
+ "Frequency", "44100",
+ "ResamplingMode", "3", /* SRCMODE_POLYPHASE */
+ "ReverbDepth", "30",
+ "ReverbDelay", "100",
+ "BassAmount", "40",
+ "BassRange", "30",
+ "SurroundDepth", "20",
+ "SurroundDelay", "20",
+ "LoopCount", "0",
+ NULL};
 
 void ModplugXMMS::Init(void)
 {
-	ConfigDb *db;
-	
-	db = aud_cfg_db_open();
+	aud_config_set_defaults (MODPLUG_CFGID, modplug_defaults);
 
-	aud_cfg_db_get_bool(db, MODPLUG_CFGID,"Surround", &mModProps.mSurround);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"Oversampling", &mModProps.mOversamp);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"Megabass", &mModProps.mMegabass);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"NoiseReduction", &mModProps.mNoiseReduction);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"VolumeRamp", &mModProps.mVolumeRamp);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"Reverb", &mModProps.mReverb);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"FastInfo", &mModProps.mFastinfo);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"UseFileName", &mModProps.mUseFilename);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"GrabAmigaMOD", &mModProps.mGrabAmigaMOD);
-        aud_cfg_db_get_bool(db, MODPLUG_CFGID,"PreAmp", &mModProps.mPreamp);
-        aud_cfg_db_get_float(db, MODPLUG_CFGID,"PreAmpLevel", &mModProps.mPreampLevel);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "Channels", &mModProps.mChannels);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "Bits", &mModProps.mBits);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "Frequency", &mModProps.mFrequency);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "ResamplineMode", &mModProps.mResamplingMode);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "ReverbDepth", &mModProps.mReverbDepth);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "ReverbDelay", &mModProps.mReverbDelay);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "BassAmount", &mModProps.mBassAmount);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "BassRange", &mModProps.mBassRange);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "SurroundDepth", &mModProps.mSurroundDepth);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "SurroundDelay", &mModProps.mSurroundDelay);
-        aud_cfg_db_get_int(db, MODPLUG_CFGID, "LoopCount", &mModProps.mLoopCount);
-
-	aud_cfg_db_close(db);
+	mModProps.mSurround = aud_get_bool (MODPLUG_CFGID, "Surround");
+	mModProps.mOversamp = aud_get_bool (MODPLUG_CFGID, "Oversampling");
+	mModProps.mMegabass = aud_get_bool (MODPLUG_CFGID, "Megabass");
+	mModProps.mNoiseReduction = aud_get_bool (MODPLUG_CFGID, "NoiseReduction");
+	mModProps.mVolumeRamp = aud_get_bool (MODPLUG_CFGID, "VolumeRamp");
+	mModProps.mReverb = aud_get_bool (MODPLUG_CFGID, "Reverb");
+	mModProps.mFastinfo = aud_get_bool (MODPLUG_CFGID, "FastInfo");
+	mModProps.mUseFilename = aud_get_bool (MODPLUG_CFGID, "UseFileName");
+	mModProps.mGrabAmigaMOD = aud_get_bool (MODPLUG_CFGID, "GrabAmigaMOD");
+	mModProps.mPreamp = aud_get_bool (MODPLUG_CFGID, "PreAmp");
+	mModProps.mPreampLevel = aud_get_double (MODPLUG_CFGID, "PreAmpLevel");
+	mModProps.mChannels = aud_get_int (MODPLUG_CFGID, "Channels");
+	mModProps.mBits = aud_get_int (MODPLUG_CFGID, "Bits");
+	mModProps.mFrequency = aud_get_int (MODPLUG_CFGID, "Frequency");
+	mModProps.mResamplingMode = aud_get_int (MODPLUG_CFGID, "ResamplineMode");
+	mModProps.mReverbDepth = aud_get_int (MODPLUG_CFGID, "ReverbDepth");
+	mModProps.mReverbDelay = aud_get_int (MODPLUG_CFGID, "ReverbDelay");
+	mModProps.mBassAmount = aud_get_int (MODPLUG_CFGID, "BassAmount");
+	mModProps.mBassRange = aud_get_int (MODPLUG_CFGID, "BassRange");
+	mModProps.mSurroundDepth = aud_get_int (MODPLUG_CFGID, "SurroundDepth");
+	mModProps.mSurroundDelay = aud_get_int (MODPLUG_CFGID, "SurroundDelay");
+	mModProps.mLoopCount = aud_get_int (MODPLUG_CFGID, "LoopCount");
 }
 
 bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
@@ -111,7 +99,8 @@ bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
 	const int magicSize = 32;
 	char magic[magicSize];
 
-	aud_vfs_fread(magic, 1, magicSize, file);
+	if (vfs_fread(magic, 1, magicSize, file) < magicSize)
+		return false;
 	if (!memcmp(magic, UMX_MAGIC, 4))
 		return true;
 	if (!memcmp(magic, "Extended Module:", 16))
@@ -125,14 +114,18 @@ bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
 	if (!memcmp(magic, PSM_MAGIC, 4))
 		return true;
 
-	aud_vfs_fseek(file, 44, SEEK_SET);
-	aud_vfs_fread(magic, 1, 4, file);
+	if (vfs_fseek(file, 44, SEEK_SET))
+		return false;
+	if (vfs_fread(magic, 1, 4, file) < 4)
+		return false;
 	if (!memcmp(magic, S3M_MAGIC, 4))
 		return true;
 
-	aud_vfs_fseek(file, 1080, SEEK_SET);
-	aud_vfs_fread(magic, 1, 4, file);
-	
+	if (vfs_fseek(file, 1080, SEEK_SET))
+		return false;
+	if (vfs_fread(magic, 1, 4, file) < 4)
+		return false;
+
 	// Check for Fast Tracker multichannel modules (xCHN, xxCH)
 	if (magic[1] == 'C' && magic[2] == 'H' && magic[3] == 'N') {
 		if (magic[0] == '6' || magic[0] == '8')
@@ -143,7 +136,7 @@ bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
 		if ((nch % 2 == 0) && nch >= 10)
 			return true;
 	}
-	
+
 	// Check for Amiga MOD module formats
 	if(mModProps.mGrabAmigaMOD) {
 	if (!memcmp(magic, MOD_MAGIC_PROTRACKER4, 4))
@@ -188,6 +181,8 @@ bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
 		return true;
 	if (lExt == ".dbf")
 		return true;
+	if (lExt == ".dmf")
+		return true;
 	if (lExt == ".dsm")
 		return true;
 	if (lExt == ".far")
@@ -198,70 +193,48 @@ bool ModplugXMMS::CanPlayFileFromVFS(const string& aFilename, VFSFile *file)
 		return true;
 	if (lExt == ".ult")
 		return true;
-	if (lExt == ".j2b")
-		return true;
 	if (lExt == ".mt2")
 		return true;
 
-	if (lExt == ".mdz")
-		return true;
-	if (lExt == ".mdr")
-		return true;
-	if (lExt == ".mdgz")
-		return true;
-	if (lExt == ".mdbz")
-		return true;
-	if (lExt == ".s3z")
-		return true;
-	if (lExt == ".s3r")
-		return true;
-	if (lExt == ".s3gz")
-		return true;
-	if (lExt == ".xmz")
-		return true;
-	if (lExt == ".xmr")
-		return true;
-	if (lExt == ".xmgz")
-		return true;
-	if (lExt == ".itz")
-		return true;
-	if (lExt == ".itr")
-		return true;
-	if (lExt == ".itgz")
-		return true;
-	if (lExt == ".dmf")
-		return true;
-	
-	if (lExt == ".zip")
-		return ContainsMod(aFilename);
-	if (lExt == ".gz")
-		return ContainsMod(aFilename);
-	if (lExt == ".bz2")
-		return ContainsMod(aFilename);
-
 	return false;
 }
 
 void ModplugXMMS::PlayLoop(InputPlayback *playback)
 {
 	uint32 lLength;
-	//the user might change the number of channels while playing.
-	// we don't want this to take effect until we are done!
-	uint8 lChannels = mModProps.mChannels;
 
-	while(!mStopped)
-	{
-		if(!(lLength = mSoundFile->Read(
-				mBuffer,
-				mBufSize)))
-		{
-			//no more to play.  Wait for output to finish and then stop.
-			while((mOutPlug->buffer_playing())
-			   && (!mStopped))
-				usleep(10000);
-			break;
-		}
-		
+    g_mutex_lock (control_mutex);
+    seek_time = -1;
+    stop_flag = FALSE;
+    playback->set_pb_ready (playback);
+    g_mutex_unlock (control_mutex);
+
+    while (1)
+    {
+        g_mutex_lock (control_mutex);
+
+        if (stop_flag)
+        {
+            g_mutex_unlock (control_mutex);
+            break;
+        }
+
+        if (seek_time != -1)
+        {
+            mSoundFile->SetCurrentPos (seek_time * (gint64)
+             mSoundFile->GetMaxPosition () / (mSoundFile->GetSongTime () * 1000));
+            playback->output->flush (seek_time);
+            seek_time = -1;
+            g_cond_signal (control_cond);
+        }
+
+        g_mutex_unlock (control_mutex);
+
+        lLength = mSoundFile->Read (mBuffer, mBufSize);
+
+        if (! lLength)
+            break;
+
 		if(mModProps.mPreamp)
 		{
 			//apply preamp
@@ -272,10 +245,10 @@ void ModplugXMMS::PlayLoop(InputPlayback *playback)
 					short old = ((short*)mBuffer)[i];
 					((short*)mBuffer)[i] *= (short int)mPreampFactor;
 					// detect overflow and clip!
-					if ((old & 0x8000) != 
+					if ((old & 0x8000) !=
 					 (((short*)mBuffer)[i] & 0x8000))
 					  ((short*)mBuffer)[i] = old | 0x7FFF;
-						
+
 				}
 			}
 			else
@@ -284,40 +257,24 @@ void ModplugXMMS::PlayLoop(InputPlayback *playback)
 					uchar old = ((uchar*)mBuffer)[i];
 					((uchar*)mBuffer)[i] *= (short int)mPreampFactor;
 					// detect overflow and clip!
-					if ((old & 0x80) != 
+					if ((old & 0x80) !=
 					 (((uchar*)mBuffer)[i] & 0x80))
 					  ((uchar*)mBuffer)[i] = old | 0x7F;
 				}
 			}
 		}
-		
-		if(mStopped)
-			break;
-	
-		//wait for buffer space to free up.
-		while(((mOutPlug->buffer_free()
-		    < (int)mBufSize))
-		   && (!mStopped))
-			usleep(10000);
-			
-		if(mStopped)
-			break;
-		
-		playback->pass_audio
-		(
-			playback,
-			mFormat,
-			lChannels,
-			mBufSize,
-			mBuffer,
-			NULL
-		);
 
-		mPlayed += mBufTime;
+        playback->output->write_audio (mBuffer, mBufSize);
 	}
 
-//	mOutPlug->flush(0);
-	mOutPlug->close_audio();
+    g_mutex_lock (control_mutex);
+
+    while (!stop_flag && playback->output->buffer_playing ())
+        g_usleep (10000);
+
+    stop_flag = TRUE;
+    g_cond_signal (control_cond); /* wake up any waiting request */
+    g_mutex_unlock (control_mutex);
 
 	//Unload the file
 	mSoundFile->Destroy();
@@ -328,29 +285,21 @@ void ModplugXMMS::PlayLoop(InputPlayback *playback)
 		delete [] mBuffer;
 		mBuffer = NULL;
 	}
-
-	mPaused = false;
-	mStopped = true;
 }
 
-void ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
+bool ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 {
-	int32 aLength=0;
-	char *aModName=NULL;
-	mStopped = true;
-	mPaused = false;
-	
 	//open and mmap the file
 	mArchive = OpenArchive(aFilename);
 	if(mArchive->Size() == 0)
 	{
 		delete mArchive;
-		return;
+		return true;
 	}
-	
+
 	if (mBuffer)
 		delete [] mBuffer;
-	
+
 	//find buftime to get approx. 512 samples/block
 	mBufTime = 512000 / mModProps.mFrequency + 1;
 
@@ -362,7 +311,7 @@ void ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 
 	mBuffer = new uchar[mBufSize];
 	if(!mBuffer)
-		return;             //out of memory!
+		return true;        //out of memory!
 
 	CSoundFile::SetWaveConfig
 	(
@@ -380,7 +329,7 @@ void ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 		mModProps.mNoiseReduction,
 		false
 	);
-	
+
 	// [Reverb level 0(quiet)-100(loud)], [delay in ms, usually 40-200ms]
 	if(mModProps.mReverb)
 	{
@@ -411,93 +360,72 @@ void ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 	CSoundFile::SetResamplingMode(mModProps.mResamplingMode);
 	mSoundFile->SetRepeatCount(mModProps.mLoopCount);
 	mPreampFactor = exp(mModProps.mPreampLevel);
-	
-	mPaused = false;
-	mStopped = false;
 
 	mSoundFile->Create
 	(
 		(uchar*)mArchive->Map(),
 		mArchive->Size()
 	);
-	mPlayed = 0;
 
-        Tuple* ti = GetSongTuple( aFilename );
-        if ( ti )
-                aModName = format_and_free_ti( ti, &aLength );
+    Tuple* ti = GetSongTuple( aFilename );
+    if ( ti ) {
+        ipb->set_tuple(ipb,ti);
+    }
 
-	ipb->set_params
-	(
-		ipb,
-		aModName,
-		aLength,
-		mSoundFile->GetNumChannels() * 1000,
-		mModProps.mFrequency,
-		mModProps.mChannels
-	);
-
-	mStopped = mPaused = false;
+	ipb->set_params(ipb, mSoundFile->GetNumChannels() * 1000, mModProps.mFrequency,	mModProps.mChannels);
 
 	if(mModProps.mBits == 16)
 		mFormat = FMT_S16_NE;
 	else
 		mFormat = FMT_U8;
 
-	mOutPlug->open_audio
-	(
-		mFormat,
-		mModProps.mFrequency,
-		mModProps.mChannels
-	);
+    if (! ipb->output->open_audio (mFormat, mModProps.mFrequency,
+     mModProps.mChannels))
+        return true;
 
-	mDecodeThread = g_thread_self();
-	ipb->set_pb_ready(ipb);
 	this->PlayLoop(ipb);
+	ipb->output->close_audio ();
+
+    return false;
 }
 
-void ModplugXMMS::Stop(void)
+void ModplugXMMS::Stop (InputPlayback * playback)
 {
-	if(mStopped)
-		return;
+	g_mutex_lock(control_mutex);
 
-	mStopped = true;
-	mPaused = false;
-	
-	g_thread_join(mDecodeThread);
+	if (!stop_flag)
+	{
+		stop_flag = TRUE;
+		playback->output->abort_write();
+		g_cond_signal(control_cond);
+	}
+
+	g_mutex_unlock(control_mutex);
 }
 
-void ModplugXMMS::Pause(bool aPaused)
+void ModplugXMMS::pause (InputPlayback * playback, gboolean pause)
 {
-	if(aPaused)
-		mPaused = true;
-	else
-		mPaused = false;
-	
-	mOutPlug->pause(aPaused);
+	g_mutex_lock(control_mutex);
+
+	if (!stop_flag)
+		playback->output->pause(pause);
+
+	g_mutex_unlock(control_mutex);
 }
 
-void ModplugXMMS::Seek(float32 aTime)
+void ModplugXMMS::mseek (InputPlayback * playback, gint time)
 {
-	uint32  lMax;
-	uint32  lMaxtime;
-	float32 lPostime;
-	
-	if(aTime > (lMaxtime = mSoundFile->GetSongTime()))
-		aTime = lMaxtime;
-	lMax = mSoundFile->GetMaxPosition();
-	lPostime = float(lMax) / lMaxtime;
+    g_mutex_lock (control_mutex);
 
-	mSoundFile->SetCurrentPos(int(aTime * lPostime));
+    if (!stop_flag)
+    {
+        seek_time = time;
+        playback->output->abort_write();
+        g_cond_signal (control_cond);
+        g_cond_wait (control_cond, control_mutex);
+    }
 
-	mOutPlug->flush(int(aTime * 1000));
-	mPlayed = uint32(aTime * 1000);
-}
-
-float32 ModplugXMMS::GetTime(void)
-{
-	if ((mStopped) || (!mOutPlug))
-		return -1;
-	return (float32)mOutPlug->output_time() / 1000;
+    g_mutex_unlock (control_mutex);
 }
 
 Tuple* ModplugXMMS::GetSongTuple(const string& aFilename)
@@ -505,7 +433,7 @@ Tuple* ModplugXMMS::GetSongTuple(const string& aFilename)
 	CSoundFile* lSoundFile;
 	Archive* lArchive;
 	const gchar *tmps;
-	
+
 	//open and mmap the file
         lArchive = OpenArchive(aFilename);
         if(lArchive->Size() == 0)
@@ -514,10 +442,10 @@ Tuple* ModplugXMMS::GetSongTuple(const string& aFilename)
                 return NULL;
         }
 
-	Tuple *ti = aud_tuple_new_from_filename(aFilename.c_str());
+	Tuple *ti = tuple_new_from_filename(aFilename.c_str());
 	lSoundFile = new CSoundFile;
 	lSoundFile->Create((uchar*)lArchive->Map(), lArchive->Size());
-	
+
 	switch(lSoundFile->GetType())
         {
 	case MOD_TYPE_MOD:	tmps = "ProTracker"; break;
@@ -543,17 +471,17 @@ Tuple* ModplugXMMS::GetSongTuple(const string& aFilename)
 	case MOD_TYPE_PSM:	tmps = "Protracker Studio Module"; break;
 	default:		tmps = "ModPlug unknown"; break;
 	}
-	aud_tuple_associate_string(ti, FIELD_CODEC, NULL, tmps);
-	aud_tuple_associate_string(ti, FIELD_QUALITY, NULL, "sequenced");
-	aud_tuple_associate_int(ti, FIELD_LENGTH, NULL, lSoundFile->GetSongTime() * 1000);
-	
+	tuple_set_str(ti, FIELD_CODEC, NULL, tmps);
+	tuple_set_str(ti, FIELD_QUALITY, NULL, "sequenced");
+	tuple_set_int(ti, FIELD_LENGTH, NULL, lSoundFile->GetSongTime() * 1000);
+
 	gchar *tmps2 = MODPLUG_CONVERT(lSoundFile->GetTitle());
 	// Chop any leading spaces off. They are annoying in the playlist.
 	gchar *tmps3 = tmps2; // Make another pointer so tmps2 can still be free()d
 	while ( *tmps3 == ' ' ) tmps3++ ;
-	aud_tuple_associate_string(ti, FIELD_TITLE, NULL, tmps3);
+	tuple_set_str(ti, FIELD_TITLE, NULL, tmps3);
 	g_free(tmps2);
-	
+
 	//unload the file
 	lSoundFile->Destroy();
 	delete lSoundFile;
@@ -565,10 +493,6 @@ void ModplugXMMS::SetInputPlugin(InputPlugin& aInPlugin)
 {
 	mInPlug = &aInPlugin;
 }
-void ModplugXMMS::SetOutputPlugin(OutputPlugin& aOutPlugin)
-{
-	mOutPlug = &aOutPlugin;
-}
 
 const ModplugXMMS::Settings& ModplugXMMS::GetModProps()
 {
@@ -585,7 +509,6 @@ const char* ModplugXMMS::Bool2OnOff(bool aValue)
 
 void ModplugXMMS::SetModProps(const Settings& aModProps)
 {
-	ConfigDb *db;
 	mModProps = aModProps;
 
 	// [Reverb level 0(quiet)-100(loud)], [delay in ms, usually 40-200ms]
@@ -636,32 +559,28 @@ void ModplugXMMS::SetModProps(const Settings& aModProps)
 	CSoundFile::SetResamplingMode(mModProps.mResamplingMode);
 	mPreampFactor = exp(mModProps.mPreampLevel);
 
-	db = aud_cfg_db_open();
-
-	aud_cfg_db_set_bool(db, MODPLUG_CFGID,"Surround", mModProps.mSurround);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"Oversampling", mModProps.mOversamp);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"Megabass", mModProps.mMegabass);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"NoiseReduction", mModProps.mNoiseReduction);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"VolumeRamp", mModProps.mVolumeRamp);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"Reverb", mModProps.mReverb);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"FastInfo", mModProps.mFastinfo);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"UseFileName", mModProps.mUseFilename);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"GrabAmigaMOD", mModProps.mGrabAmigaMOD);
-        aud_cfg_db_set_bool(db, MODPLUG_CFGID,"PreAmp", mModProps.mPreamp);
-        aud_cfg_db_set_float(db, MODPLUG_CFGID,"PreAmpLevel", mModProps.mPreampLevel);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "Channels", mModProps.mChannels);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "Bits", mModProps.mBits);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "Frequency", mModProps.mFrequency);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "ResamplineMode", mModProps.mResamplingMode);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "ReverbDepth", mModProps.mReverbDepth);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "ReverbDelay", mModProps.mReverbDelay);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "BassAmount", mModProps.mBassAmount);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "BassRange", mModProps.mBassRange);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "SurroundDepth", mModProps.mSurroundDepth);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "SurroundDelay", mModProps.mSurroundDelay);
-        aud_cfg_db_set_int(db, MODPLUG_CFGID, "LoopCount", mModProps.mLoopCount);
-
-	aud_cfg_db_close(db);
+	aud_set_bool (MODPLUG_CFGID, "Surround", mModProps.mSurround);
+	aud_set_bool (MODPLUG_CFGID, "Oversampling", mModProps.mOversamp);
+	aud_set_bool (MODPLUG_CFGID, "Megabass", mModProps.mMegabass);
+	aud_set_bool (MODPLUG_CFGID, "NoiseReduction", mModProps.mNoiseReduction);
+	aud_set_bool (MODPLUG_CFGID, "VolumeRamp", mModProps.mVolumeRamp);
+	aud_set_bool (MODPLUG_CFGID, "Reverb", mModProps.mReverb);
+	aud_set_bool (MODPLUG_CFGID, "FastInfo", mModProps.mFastinfo);
+	aud_set_bool (MODPLUG_CFGID, "UseFileName", mModProps.mUseFilename);
+	aud_set_bool (MODPLUG_CFGID, "GrabAmigaMOD", mModProps.mGrabAmigaMOD);
+	aud_set_bool (MODPLUG_CFGID, "PreAmp", mModProps.mPreamp);
+	aud_set_double (MODPLUG_CFGID, "PreAmpLevel", mModProps.mPreampLevel);
+	aud_set_int (MODPLUG_CFGID, "Channels", mModProps.mChannels);
+	aud_set_int (MODPLUG_CFGID, "Bits", mModProps.mBits);
+	aud_set_int (MODPLUG_CFGID, "Frequency", mModProps.mFrequency);
+	aud_set_int (MODPLUG_CFGID, "ResamplineMode", mModProps.mResamplingMode);
+	aud_set_int (MODPLUG_CFGID, "ReverbDepth", mModProps.mReverbDepth);
+	aud_set_int (MODPLUG_CFGID, "ReverbDelay", mModProps.mReverbDelay);
+	aud_set_int (MODPLUG_CFGID, "BassAmount", mModProps.mBassAmount);
+	aud_set_int (MODPLUG_CFGID, "BassRange", mModProps.mBassRange);
+	aud_set_int (MODPLUG_CFGID, "SurroundDepth", mModProps.mSurroundDepth);
+	aud_set_int (MODPLUG_CFGID, "SurroundDelay", mModProps.mSurroundDelay);
+	aud_set_int (MODPLUG_CFGID, "LoopCount", mModProps.mLoopCount);
 }
 
 ModplugXMMS gModplugXMMS;
