@@ -22,6 +22,8 @@
 /* must come before <mpg123.h> to get _FILE_OFFSET_BITS */
 #include "config.h"
 
+#include <glib.h>
+#include <string.h>
 #include <mpg123.h>
 
 #ifdef DEBUG_MPG123_IO
@@ -184,11 +186,11 @@ static Tuple * mpg123_probe_for_tuple (const gchar * filename, VFSFile * file)
 
 	Tuple * tuple = tuple_new_from_filename (filename);
 	make_format_string (& info, scratch, sizeof scratch);
-	tuple_associate_string (tuple, FIELD_CODEC, NULL, scratch);
+	tuple_set_str (tuple, FIELD_CODEC, NULL, scratch);
 	snprintf (scratch, sizeof scratch, "%s, %d Hz", (channels == 2)
 	 ? _("Stereo") : (channels > 2) ? _("Surround") : _("Mono"), (gint) rate);
-	tuple_associate_string (tuple, FIELD_QUALITY, NULL, scratch);
-	tuple_associate_int (tuple, FIELD_BITRATE, NULL, info.bitrate);
+	tuple_set_str (tuple, FIELD_QUALITY, NULL, scratch);
+	tuple_set_int (tuple, FIELD_BITRATE, NULL, info.bitrate);
 
 	if (! vfs_is_streaming (file))
 	{
@@ -197,9 +199,9 @@ static Tuple * mpg123_probe_for_tuple (const gchar * filename, VFSFile * file)
 		gint length = (samples > 0) ? samples * 1000 / rate : 0;
 
 		if (length > 0)
-			tuple_associate_int (tuple, FIELD_LENGTH, NULL, length);
+			tuple_set_int (tuple, FIELD_LENGTH, NULL, length);
 		if (size > 0 && length > 0)
-			tuple_associate_int (tuple, FIELD_BITRATE, NULL, 8 * size / length);
+			tuple_set_int (tuple, FIELD_BITRATE, NULL, 8 * size / length);
 	}
 
 	mpg123_delete (decoder);
@@ -243,14 +245,15 @@ get_stream_metadata(VFSFile *file, const gchar *name)
 static gboolean
 update_stream_metadata(VFSFile *file, const gchar *name, Tuple *tuple, gint item)
 {
-	const gchar *old = tuple_get_string(tuple, item, NULL);
+	gchar *old = tuple_get_str(tuple, item, NULL);
 	gchar *new = get_stream_metadata(file, name);
 	gboolean changed = (new != NULL && (old == NULL || strcmp(old, new)));
 
 	if (changed)
-		tuple_associate_string(tuple, item, NULL, new);
+		tuple_set_str(tuple, item, NULL, new);
 
 	g_free(new);
+	str_unref(old);
 	return changed;
 }
 
@@ -264,7 +267,7 @@ static Tuple * get_stream_tuple (InputPlayback * p, const gchar * filename,
 	update_stream_metadata (file, "track-name", tuple, FIELD_TITLE);
 	update_stream_metadata (file, "stream-name", tuple, FIELD_ARTIST);
 
-	mowgli_object_ref (tuple);
+	tuple_ref (tuple);
 	p->set_tuple (p, tuple);
 
 	return tuple;
@@ -276,7 +279,7 @@ static void update_stream_tuple (InputPlayback * p, VFSFile * file,
 	if (update_stream_metadata (file, "track-name", tuple, FIELD_TITLE) ||
 	 update_stream_metadata (file, "stream-name", tuple, FIELD_ARTIST))
 	{
-		mowgli_object_ref (tuple);
+		tuple_ref (tuple);
 		p->set_tuple (p, tuple);
 	}
 }
@@ -483,7 +486,7 @@ decode_cleanup:
 cleanup:
 	mpg123_delete(ctx.decoder);
 	if (ctx.tu)
-		tuple_free (ctx.tu);
+		tuple_unref (ctx.tu);
 	return ! error;
 }
 
@@ -538,7 +541,7 @@ static gboolean mpg123_write_tag (const Tuple * tuple, VFSFile * handle)
 }
 
 static gboolean mpg123_get_image (const gchar * filename, VFSFile * handle,
- void * * data, gint * length)
+ void * * data, gint64 * length)
 {
 	if (! handle || vfs_is_streaming (handle))
 		return FALSE;
