@@ -2,7 +2,6 @@
 #define XS_CONFIG_H
 
 #include "xmms-sid.h"
-#include "xs_curve.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -68,13 +67,35 @@ enum XS_SIDMODEL {
 
 
 typedef struct {
-    t_xs_int_point    points[XS_SIDPLAY2_NFPOINTS];
-    gint        npoints;
-    gchar        *name;
-} t_xs_sid2_filter;
+    gint x, y;
+} xs_int_point_t;
 
 
-extern struct t_xs_cfg {
+typedef struct {
+    gchar           *name;
+    gint            type;
+
+    /* Filter type 0 for SIDPlay 1 */
+    gfloat          fs, fm, ft;
+
+    /* Filter type 1-2 points */
+    xs_int_point_t  points[XS_SIDPLAY2_NFPOINTS];
+    gint            npoints;
+
+    /* Distortion patch tunables */
+    gfloat          rate, point, voice_nonlinearity,
+                    cf_treshold;
+
+    /* Filter Type 3 tunables */
+    gfloat          baseresistance, offset, steepness,
+                    minimumfetresistance;
+
+    /* Filter Type 4 tunables */
+    gfloat          k, b;
+} xs_sid_filter_t;
+
+
+extern struct xs_cfg_t {
     /* General audio settings */
     gint        audioBitsPerSample;
     gint        audioChannels;
@@ -93,17 +114,15 @@ extern struct t_xs_cfg {
     gint        playerEngine;       /* Selected player engine */
 
     gboolean    emulateFilters;
-    gfloat      sid1FilterFs;
-    gfloat      sid1FilterFm;
-    gfloat      sid1FilterFt;
+    xs_sid_filter_t    sid1Filter;  /* Current SIDPlay1 filter */
 
     gint        sid2OptLevel;       /* SIDPlay2 emulation optimization */
     gint        sid2Builder;        /* SIDPlay2 "builder" aka SID-emu */
-    t_xs_sid2_filter    sid2Filter; /* Current SIDPlay2 filter */
-    t_xs_sid2_filter    **sid2FilterPresets;
+    xs_sid_filter_t    sid2Filter;  /* Current SIDPlay2 filter */
+    xs_sid_filter_t    **sid2FilterPresets;
     gint        sid2NFilterPresets;
-    
-    
+
+
     /* Playing settings */
     gboolean    playMaxTimeEnable,
                 playMaxTimeUnknown; /* Use max-time only when song-length is unknown */
@@ -158,7 +177,7 @@ typedef struct {
     gint    itemType;   /* Type of item (CTYPE_*) */
     void    *itemData;  /* Pointer to variable */
     gchar   *itemName;  /* Name of configuration item */
-} t_xs_cfg_item;
+} xs_cfg_item_t;
 
 
 typedef struct {
@@ -167,15 +186,12 @@ typedef struct {
     gchar   *widName;
     void    *itemData;
     gint    itemSet;
-} t_xs_wid_item;
+} xs_wid_item_t;
 
 
 /* Functions
  */
 void    xs_init_configuration(void);
-void    xs_configure(void);
-void    xs_read_configuration(void);
-gint    xs_write_configuration(void);
 
 #ifdef __cplusplus
 }
